API Reference
=============

Electoral Roll
--------------

.. automodule:: serveliza.roll
    :members:

|Roll|

Modules
~~~~~~~

* Main module: :mod:`serveliza.roll.roll`
* Auxiliary modules:
    * :mod:`serveliza.roll.adapters`
    * :mod:`serveliza.roll.parsers`
    * :mod:`serveliza.roll.memorizer`
    * :mod:`serveliza.roll.exporter`
    * :mod:`serveliza.roll.printer`

Main class
~~~~~~~~~~

.. automodule:: serveliza.roll.roll
    :members:

Roll adapters
~~~~~~~~~~~~~

.. automodule:: serveliza.roll.adapters
    :members:

Roll parsers
~~~~~~~~~~~~

.. automodule:: serveliza.roll.parsers
    :members:

Roll memorizer
~~~~~~~~~~~~~~

.. automodule:: serveliza.roll.memorizer
    :members:

Roll exporter
~~~~~~~~~~~~~

.. automodule:: serveliza.roll.exporter
    :members:

Roll printer
~~~~~~~~~~~~

.. automodule:: serveliza.roll.printer
    :members:


Mixins modules
--------------

* :mod:`serveliza.mixins.pdf`
* :mod:`serveliza.mixins.pdf_processors`

.. automodule:: serveliza.mixins
    :members:

PDF processor mixin
-------------------
.. automodule:: serveliza.mixins.pdf
    :members:

Available PDF processors
------------------------

.. automodule:: serveliza.mixins.pdf_processors
    :members:


.. |Roll| image:: https://github.com/chivke/serveliza/raw/master/images/serveliza_roll.gif
    :align: middle
    :alt: Electoral roll example gif
    :width: 80%